type ShakuDirectiveUnderline = {
    type: "DirectiveUnderline";
    config: {
        style: "solid" | "dotted" | "wavy";
        content: string;
        offset: number;
    };
};
type ShakuAnnotationLine = {
    type: "AnnotationLine";
    config: {
        offset: number;
        content: string;
    };
};
type ShakuDirectiveCallout = {
    type: "DirectiveCallout";
    config: {
        offset: number;
    };
};
type ShakuDirectiveCollapse = {
    type: "DirectiveCollapse";
    config: {
        offset: number;
        mark: "start" | "end";
    };
};
type ShakuDirectiveHighlight = {
    type: "DirectiveHighlight";
    config: {
        mark: "start" | "end" | "below";
    };
};
type ShakuLine = ShakuDirectiveUnderline | ShakuAnnotationLine | ShakuDirectiveCallout | ShakuDirectiveCollapse | ShakuDirectiveHighlight;
declare const parseLine: (line: string) => ShakuLine | null;
declare function shouldApplyAnnotation(meta: string): boolean;
/**
 * Thought we process by lines, but we need to render in blocks, for instance:
 * A full callout normally contains:
 * 1. DirectiveCallout
 * 2. one or more AnnotationLine
 *
 * An underline annotation contains:
 * 1. DirectiveUnderline
 * 2. one ore more AnnotationLine
 *
 * DirectiveCollapse also render a few lines of source code
 * So this function should render component
 */
type ShakuComponentCallout = {
    type: "ShakuComponentCallout";
    config: {
        offset: number;
        arrowOffset: number;
        contents: string[];
    };
};
type ShakuComponentUnderline = {
    type: "ShakuComponentUnderline";
    config: {
        offset: number;
        underlineOffset: number;
        underlineContent: string;
        underlineStyle: "solid" | "dotted" | "wavy";
        contents: string[];
    };
};
type ShakuComponent = ShakuComponentCallout | ShakuComponentUnderline;
declare function renderComponent(component: ShakuComponent): string | undefined;

export { parseLine, renderComponent, shouldApplyAnnotation };
